From e65b04a9bf37a5aa108d8b2e9d5b42c3edc7f952 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Wed, 10 Feb 2010 08:25:34 -0500
Subject: [PATCH] Fixed general utf8 encoding problems when data is passed from frontend to server, this fixes also bug FS#1065 - Special characters in autoresponder subject may break the autoresponder 

---
 interface/web/mail/mail_user_stats.php |    7 ++-----
 1 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/interface/web/mail/mail_user_stats.php b/interface/web/mail/mail_user_stats.php
index ad431e9..f7858aa 100644
--- a/interface/web/mail/mail_user_stats.php
+++ b/interface/web/mail/mail_user_stats.php
@@ -12,11 +12,8 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'mail')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('mail');
 
 $app->load('listform_actions');
 

--
Gitblit v1.9.1